<?php
/**
 * sylvia functions and definitions
 *
 * @package sylvia
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) ) {
	$content_width = 819; /* pixels */
}

if ( ! function_exists( 'sylvia_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function sylvia_setup() {

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on sylvia, use a find and replace
	 * to change 'sylvia' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'sylvia', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );
	/**
	* Adding support for the post thumbnails
	*/
	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 800, 530, true );
	add_image_size('large-image-thumb', 800, 530, true );
	
	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	//add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'sylvia' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 * See http://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'aside', 'image', 'video', 'quote', 'link',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'sylvia_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );
	
	add_theme_support( 'woocommerce' );
	
}
endif; // sylvia_setup
add_action( 'after_setup_theme', 'sylvia_setup' );



// Setting up max length on excerpt
function custom_excerpt_length( $length ) {
	return 20;
}
add_filter( 'excerpt_length', 'custom_excerpt_length', 999 );


/**
 * Register widget area.
 *
 * @link http://codex.wordpress.org/Function_Reference/register_sidebar
 */
function sylvia_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'sylvia' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title"><span>',
		'after_title'   => '</span></h3>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Frontbar', 'sylvia' ),
		'id'            => 'frontbar-1',
		'description'   => '',
		'before_widget' => '<div id="%1$s" class="%2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="entry-title"><span>',
		'after_title'   => '</span></h2>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Frontfeat', 'sylvia' ),
		'id'            => 'frontfeat-1',
		'description'   => '',
		'before_widget' => '<div id="%1$s" class="%2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="entry-title"><span>',
		'after_title'   => '</span></h3>',
	) );
	register_sidebar( array(
		'name'          => __( 'Footer 1', 'sylvia' ),
		'id'            => 'footer-1',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h4 class="widget-title"><span>',
		'after_title'   => '</span></h4>',
	) );
	register_sidebar( array(
		'name'          => __( 'Footer 2', 'sylvia' ),
		'id'            => 'footer-2',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h4 class="widget-title"><span>',
		'after_title'   => '</span></h4>',
	) );
	register_sidebar( array(
		'name'          => __( 'Footer 3', 'sylvia' ),
		'id'            => 'footer-3',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h4 class="widget-title"><span>',
		'after_title'   => '</span></h4>',
	) );
	register_sidebar( array(
		'name'          => __( 'Footer 4', 'sylvia' ),
		'id'            => 'footer-4',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h4 class="widget-title"><span>',
		'after_title'   => '</span></h4>',
	) );
}
add_action( 'widgets_init', 'sylvia_widgets_init' );



/**
 * Register Playfair and Fauna Google fonts.
 */
function sylvia_fonts_url() {
    $fonts_url = '';
 
    /* Translators: If there are characters in your language that are not
    * supported by the Google fonts, translate this to 'off'. Do not translate
    * into your own language.
    */
    $playfair = _x( 'on', 'Playfair font: on or off', 'sylvia' );
	$fauna = _x( 'on', 'Fauna font: on or off', 'sylvia' );
  
    if ( 'off' !== $playfair || 'off' !== $fauna ) {
        $font_families = array();
 
        if ( 'off' !== $playfair ) {
            $font_families[] = 'Playfair Display:400,700,400italic';
        }
		
		if ( 'off' !== $fauna ) {
            $font_families[] = 'Fauna One:400,700,400italic';
        }
 
        $query_args = array(
            'family' => urlencode( implode( '|', $font_families ) ),
            'subset' => urlencode( 'latin,latin-ext' ),
        );
 
        $fonts_url = add_query_arg( $query_args, '//fonts.googleapis.com/css' );
    }
 
    return $fonts_url;
}


/**
 * Enqueue scripts and styles.
 */
function sylvia_scripts() {

	wp_enqueue_style( 'sylvia-style', get_stylesheet_uri() );

	// Load custom css defining responsivity, grids etc.
	wp_enqueue_style( 'sylvia-customcss', get_template_directory_uri() . '/css/custom.css' );
	// Load slicknav css
	wp_enqueue_style( 'sylvia-slicknav-css', get_template_directory_uri() . '/css/slicknav.css' );
	// Load google font
    wp_enqueue_style( 'sylvia-fonts', sylvia_fonts_url(), array(), null );
	
	// Load jQuery using WordPress
	wp_enqueue_script( 'jquery' );
	// Load tinynav library
	wp_enqueue_script( 'sylvia-navigation', get_template_directory_uri() . '/js/jquery.slicknav.js', array(), '20150202', true );
	
	// Execute script and set div selector class
	wp_enqueue_script( 'sylvia-loadnavigation', get_template_directory_uri() . '/js/sylvia_load.js', array(), '20150202', true );

	wp_enqueue_script( 'sylvia-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'sylvia_scripts' );

/**
 * Implement the Custom Header feature.
 */
//require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';


