<?php
/**
 * sylvia Theme Customizer
 *
 * @package sylvia
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function sylvia_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';
	
	// Add custom header and sidebar text color setting and control.
	$wp_customize->add_setting( 'accent_color', array(
		'default'           => '#003D5C',
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'         => 'refresh',
	) );
	// Add custom header and sidebar text color setting and control.
	$wp_customize->add_setting( 'link_color', array(
		'default'           => '#fff',
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'         => 'refresh',
	) );
	// Add custom header and sidebar text color setting and control.
	$wp_customize->add_setting( 'nav_color', array(
		'default'           => '#fff',
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'         => 'refresh',
	) );
	// Add custom header and sidebar text color setting and control.
	$wp_customize->add_setting( 'text_color', array(
		'default'           => '#fff',
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'         => 'refresh',
	) );
	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'accent_color', array(
		'label'       => __( 'Accent Color', 'sylvia' ),
		'description' => __( 'Used for header, footer and other accent areas.', 'sylvia' ),
		'section'     => 'colors',
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'link_color', array(
		'label'       => __( 'Link Color', 'sylvia' ),
		'description' => __( 'Used for header, footer and other accent areas.', 'sylvia' ),
		'section'     => 'colors',
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'nav_color', array(
		'label'       => __( 'Nav Color', 'sylvia' ),
		'description' => __( 'Used for header, footer and other accent areas.', 'sylvia' ),
		'section'     => 'colors',
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'text_color', array(
		'label'       => __( 'Footer Color', 'sylvia' ),
		'description' => __( 'Used for header, footer and other accent areas.', 'sylvia' ),
		'section'     => 'colors',
	) ) );
}
add_action( 'customize_register', 'sylvia_customize_register' );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function sylvia_customize_preview_js() {
	wp_enqueue_script( 'sylvia_customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20130508', true );
}
add_action( 'customize_preview_init', 'sylvia_customize_preview_js' );


function sylvia_custom_css() {
	wp_enqueue_style(
		'custom-style',
		get_template_directory_uri() . '/css/custom.css'
	);
		$color = '';
		$text_color = '';
		$nav_color = '';
		$link_color = '';
        $color = esc_attr( get_theme_mod( 'accent_color', '#003D5C' ) ); 
		$nav_color = esc_attr( get_theme_mod( 'nav_color', '#00557f' ) );
		$text_color = esc_attr( get_theme_mod( 'text_color', '#FFFFFF' ) );
		$link_color = esc_attr( get_theme_mod( 'link_color', '#FFFFFF' ) ); 
		
		if ($color != '') { 
        $custom_css = "
                .header-menu{
                        background: {$color};
                }
				span.posted-on, .site-footer, .nav-previous, .nav-next{
                        background: {$color};
                }
				";
		}
		if ($nav_color != '') {
		$custom_css .= "
				.navi-menu{
						background: {$nav_color};
				}
				";
		}
		if ($text_color != '') {		
		$custom_css .="
				.site-footer p, .site-footer .textwidget, .site-footer h4.widget-title {
						color: {$text_color};
				}
				
				";
		}
		if ($link_color != '') {
		$custom_css .="
				.header-menu a, .navi-menu a, span.posted-on a, .site-footer a, .nav-prev a, .nav-next { 
					color: {$link_color};
				";
		}
        wp_add_inline_style( 'custom-style', $custom_css );
}
add_action( 'wp_enqueue_scripts', 'sylvia_custom_css' );